@@ -3,7 +3,7 @@ use warnings;
 
 package App::Cmd::Command;
 {
-  $App::Cmd::Command::VERSION = '0.316';
+  $App::Cmd::Command::VERSION = '0.320';
 }
 use App::Cmd::ArgProcessor;
 BEGIN { our @ISA = 'App::Cmd::ArgProcessor' };
@@ -143,6 +143,7 @@ sub description { '' }
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -151,7 +152,7 @@ App::Cmd::Command - a base class for App::Cmd commands
 
 =head1 VERSION
 
-version 0.316
+version 0.320
 
 =head1 METHODS
 
@@ -174,6 +175,15 @@ should use this.
 
 =head2 execute
 
+  $command_plugin->execute(\%opt, \@args);
+
+This method does whatever it is the command should do!  It is passed a hash
+reference of the parsed command-line options and an array reference of left
+over arguments.
+
+If no C<execute> method is defined, it will try to call C<run> -- but it will
+warn about this behavior during testing, to remind you to fix the method name!
+
 =head2 app
 
 This method returns the App::Cmd object into which this command is plugged.
@@ -185,12 +195,16 @@ L<Getopt::Long::Descriptive>).
 
 =head2 command_names
 
-This method returns a list of command names handled by this plugin.  If this
-method is not overridden by a App::Cmd::Command subclass, it will return the
-last part of the plugin's package name, converted to lowercase.
+This method returns a list of command names handled by this plugin. The
+first item returned is the 'canonical' name of the command.
 
+If this method is not overridden by an App::Cmd::Command subclass, it will
+return the last part of the plugin's package name, converted to lowercase.
 For example, YourApp::Cmd::Command::Init will, by default, handle the command
-"init"
+"init".
+
+Subclasses should generally get the superclass value of C<command_names>
+and then append aliases.
 
 =head2 usage_desc
 
@@ -234,31 +248,19 @@ If it can't find the abstract, it will look for a comment starting with
 =head2 description
 
 This method should be overridden to provide full option description. It
-is used by the help command.
+is used by the built-in L<App::Cmd::Command::help|help> command.
 
 If not overridden, it returns an empty string.
 
-=for Pod::Coverage run
-
-  $command_plugin->execute(\%opt, \@args);
-
-This method does whatever it is the command should do!  It is passed a hash
-reference of the parsed command-line options and an array reference of left
-over arguments.
-
-If no C<execute> method is defined, it will try to call C<run> -- but it will
-warn about this behavior during testing, to remind you to fix the method name!
-
 =head1 AUTHOR
 
 Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo Signes.
+This software is copyright (c) 2013 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
